==> duckdb_0.2.6.tar.gz: duckdb/src/duckdb/amalgamation-7.cpp <==
#include "src/planner/binder/statement/bind_insert.cpp"

#include "src/planner/binder/statement/bind_load.cpp"

#include "src/planner/binder/statement/bind_pragma.cpp"

#include "src/planner/binder/statement/bind_relation.cpp"

#include "src/planner/binder/statement/bind_select.cpp"

#include "src/planner/binder/statement/bind_set.cpp"

#include "src/planner/binder/statement/bind_show.cpp"

#include "src/planner/binder/statement/bind_simple.cpp"

#include "src/planner/binder/statement/bind_update.cpp"

#include "src/planner/binder/statement/bind_vacuum.cpp"

#include "src/planner/binder/tableref/bind_basetableref.cpp"

#include "src/planner/binder/tableref/bind_crossproductref.cpp"

#include "src/planner/binder/tableref/bind_emptytableref.cpp"

#include "src/planner/binder/tableref/bind_expressionlistref.cpp"

#include "src/planner/binder/tableref/bind_joinref.cpp"

#include "src/planner/binder/tableref/bind_named_parameters.cpp"

#include "src/planner/binder/tableref/bind_subqueryref.cpp"

#include "src/planner/binder/tableref/bind_table_function.cpp"

#include "src/planner/binder/tableref/plan_basetableref.cpp"

#include "src/planner/binder/tableref/plan_crossproductref.cpp"

#include "src/planner/binder/tableref/plan_cteref.cpp"

#include "src/planner/binder/tableref/plan_dummytableref.cpp"

#include "src/planner/binder/tableref/plan_expressionlistref.cpp"

#include "src/planner/binder/tableref/plan_joinref.cpp"

#include "src/planner/binder/tableref/plan_subqueryref.cpp"

#include "src/planner/binder/tableref/plan_table_function.cpp"

#include "src/planner/expression.cpp"

#include "src/planner/expression/bound_aggregate_expression.cpp"

#include "src/planner/expression/bound_between_expression.cpp"

#include "src/planner/expression/bound_case_expression.cpp"

#include "src/planner/expression/bound_cast_expression.cpp"

#include "src/planner/expression/bound_columnref_expression.cpp"

#include "src/planner/expression/bound_comparison_expression.cpp"

#include "src/planner/expression/bound_conjunction_expression.cpp"

#include "src/planner/expression/bound_constant_expression.cpp"

#include "src/planner/expression/bound_function_expression.cpp"

#include "src/planner/expression/bound_operator_expression.cpp"

#include "src/planner/expression/bound_parameter_expression.cpp"

#include "src/planner/expression/bound_reference_expression.cpp"

#include "src/planner/expression/bound_subquery_expression.cpp"

#include "src/planner/expression/bound_unnest_expression.cpp"

#include "src/planner/expression/bound_window_expression.cpp"

#include "src/planner/expression_binder.cpp"

#include "src/planner/expression_binder/aggregate_binder.cpp"

#include "src/planner/expression_binder/alter_binder.cpp"

#include "src/planner/expression_binder/check_binder.cpp"

#include "src/planner/expression_binder/constant_binder.cpp"

#include "src/planner/expression_binder/group_binder.cpp"

#include "src/planner/expression_binder/having_binder.cpp"

#include "src/planner/expression_binder/index_binder.cpp"

#include "src/planner/expression_binder/insert_binder.cpp"

#include "src/planner/expression_binder/order_binder.cpp"

#include "src/planner/expression_binder/relation_binder.cpp"

#include "src/planner/expression_binder/select_binder.cpp"

#include "src/planner/expression_binder/update_binder.cpp"

#include "src/planner/expression_binder/where_binder.cpp"

#include "src/planner/expression_iterator.cpp"

#include "src/planner/joinside.cpp"

#include "src/planner/logical_operator.cpp"

#include "src/planner/logical_operator_visitor.cpp"

#include "src/planner/operator/logical_aggregate.cpp"

#include "src/planner/operator/logical_any_join.cpp"

#include "src/planner/operator/logical_comparison_join.cpp"

#include "src/planner/operator/logical_cross_product.cpp"

#include "src/planner/operator/logical_distinct.cpp"

#include "src/planner/operator/logical_empty_result.cpp"

#include "src/planner/operator/logical_filter.cpp"

#include "src/planner/operator/logical_get.cpp"

#include "src/planner/operator/logical_join.cpp"

#include "src/planner/operator/logical_projection.cpp"

#include "src/planner/operator/logical_unnest.cpp"

#include "src/planner/operator/logical_window.cpp"

#include "src/planner/planner.cpp"

#include "src/planner/pragma_handler.cpp"

#include "src/planner/subquery/flatten_dependent_join.cpp"

#include "src/planner/subquery/has_correlated_expressions.cpp"

#include "src/planner/subquery/rewrite_correlated_expressions.cpp"

#include "src/planner/table_binding.cpp"

#include "src/storage/block.cpp"

#include "src/storage/buffer/buffer_handle.cpp"

#include "src/storage/buffer/buffer_list.cpp"

#include "src/storage/buffer/managed_buffer.cpp"

#include "src/storage/buffer_manager.cpp"

#include "src/storage/checkpoint/table_data_reader.cpp"

#include "src/storage/checkpoint/table_data_writer.cpp"

#include "src/storage/checkpoint/write_overflow_strings_to_disk.cpp"

#include "src/storage/checkpoint_manager.cpp"

#include "src/storage/column_data.cpp"

#include "src/storage/data_table.cpp"

#include "src/storage/index.cpp"

#include "src/storage/local_storage.cpp"

#include "src/storage/meta_block_reader.cpp"

#include "src/storage/meta_block_writer.cpp"

#include "src/storage/numeric_segment.cpp"

#include "src/storage/single_file_block_manager.cpp"

#include "src/storage/statistics/base_statistics.cpp"

#include "src/storage/statistics/numeric_statistics.cpp"

#include "src/storage/statistics/segment_statistics.cpp"

#include "src/storage/statistics/string_statistics.cpp"

#include "src/storage/statistics/validity_statistics.cpp"

==> duckdb_0.2.7.tar.gz: duckdb/src/duckdb/amalgamation-7.cpp <==
#include "src/planner/binder/statement/bind_relation.cpp"

#include "src/planner/binder/statement/bind_select.cpp"

#include "src/planner/binder/statement/bind_set.cpp"

#include "src/planner/binder/statement/bind_show.cpp"

#include "src/planner/binder/statement/bind_simple.cpp"

#include "src/planner/binder/statement/bind_update.cpp"

#include "src/planner/binder/statement/bind_vacuum.cpp"

#include "src/planner/binder/tableref/bind_basetableref.cpp"

#include "src/planner/binder/tableref/bind_crossproductref.cpp"

#include "src/planner/binder/tableref/bind_emptytableref.cpp"

#include "src/planner/binder/tableref/bind_expressionlistref.cpp"

#include "src/planner/binder/tableref/bind_joinref.cpp"

#include "src/planner/binder/tableref/bind_named_parameters.cpp"

#include "src/planner/binder/tableref/bind_subqueryref.cpp"

#include "src/planner/binder/tableref/bind_table_function.cpp"

#include "src/planner/binder/tableref/plan_basetableref.cpp"

#include "src/planner/binder/tableref/plan_crossproductref.cpp"

#include "src/planner/binder/tableref/plan_cteref.cpp"

#include "src/planner/binder/tableref/plan_dummytableref.cpp"

#include "src/planner/binder/tableref/plan_expressionlistref.cpp"

#include "src/planner/binder/tableref/plan_joinref.cpp"

#include "src/planner/binder/tableref/plan_subqueryref.cpp"

#include "src/planner/binder/tableref/plan_table_function.cpp"

#include "src/planner/expression.cpp"

#include "src/planner/expression/bound_aggregate_expression.cpp"

#include "src/planner/expression/bound_between_expression.cpp"

#include "src/planner/expression/bound_case_expression.cpp"

#include "src/planner/expression/bound_cast_expression.cpp"

#include "src/planner/expression/bound_columnref_expression.cpp"

#include "src/planner/expression/bound_comparison_expression.cpp"

#include "src/planner/expression/bound_conjunction_expression.cpp"

#include "src/planner/expression/bound_constant_expression.cpp"

#include "src/planner/expression/bound_function_expression.cpp"

#include "src/planner/expression/bound_operator_expression.cpp"

#include "src/planner/expression/bound_parameter_expression.cpp"

#include "src/planner/expression/bound_reference_expression.cpp"

#include "src/planner/expression/bound_subquery_expression.cpp"

#include "src/planner/expression/bound_unnest_expression.cpp"

#include "src/planner/expression/bound_window_expression.cpp"

#include "src/planner/expression_binder.cpp"

#include "src/planner/expression_binder/aggregate_binder.cpp"

#include "src/planner/expression_binder/alter_binder.cpp"

#include "src/planner/expression_binder/check_binder.cpp"

#include "src/planner/expression_binder/constant_binder.cpp"

#include "src/planner/expression_binder/group_binder.cpp"

#include "src/planner/expression_binder/having_binder.cpp"

#include "src/planner/expression_binder/index_binder.cpp"

#include "src/planner/expression_binder/insert_binder.cpp"

#include "src/planner/expression_binder/order_binder.cpp"

#include "src/planner/expression_binder/relation_binder.cpp"

#include "src/planner/expression_binder/select_binder.cpp"

#include "src/planner/expression_binder/update_binder.cpp"

#include "src/planner/expression_binder/where_binder.cpp"

#include "src/planner/expression_iterator.cpp"

#include "src/planner/filter/conjunction_filter.cpp"

#include "src/planner/filter/constant_filter.cpp"

#include "src/planner/filter/null_filter.cpp"

#include "src/planner/joinside.cpp"

#include "src/planner/logical_operator.cpp"

#include "src/planner/logical_operator_visitor.cpp"

#include "src/planner/operator/logical_aggregate.cpp"

#include "src/planner/operator/logical_any_join.cpp"

#include "src/planner/operator/logical_comparison_join.cpp"

#include "src/planner/operator/logical_cross_product.cpp"

#include "src/planner/operator/logical_distinct.cpp"

#include "src/planner/operator/logical_empty_result.cpp"

#include "src/planner/operator/logical_filter.cpp"

#include "src/planner/operator/logical_get.cpp"

#include "src/planner/operator/logical_join.cpp"

#include "src/planner/operator/logical_projection.cpp"

#include "src/planner/operator/logical_unnest.cpp"

#include "src/planner/operator/logical_window.cpp"

#include "src/planner/planner.cpp"

#include "src/planner/pragma_handler.cpp"

#include "src/planner/subquery/flatten_dependent_join.cpp"

#include "src/planner/subquery/has_correlated_expressions.cpp"

#include "src/planner/subquery/rewrite_correlated_expressions.cpp"

#include "src/planner/table_binding.cpp"

#include "src/planner/table_filter.cpp"

#include "src/storage/block.cpp"

#include "src/storage/buffer/buffer_handle.cpp"

#include "src/storage/buffer/buffer_list.cpp"

#include "src/storage/buffer/managed_buffer.cpp"

#include "src/storage/buffer_manager.cpp"

#include "src/storage/checkpoint/table_data_reader.cpp"

#include "src/storage/checkpoint/table_data_writer.cpp"

#include "src/storage/checkpoint/write_overflow_strings_to_disk.cpp"

#include "src/storage/checkpoint_manager.cpp"

#include "src/storage/data_table.cpp"

#include "src/storage/index.cpp"

#include "src/storage/local_storage.cpp"

#include "src/storage/meta_block_reader.cpp"

#include "src/storage/meta_block_writer.cpp"

#include "src/storage/numeric_segment.cpp"

#include "src/storage/single_file_block_manager.cpp"

#include "src/storage/statistics/base_statistics.cpp"

#include "src/storage/statistics/numeric_statistics.cpp"

#include "src/storage/statistics/segment_statistics.cpp"

#include "src/storage/statistics/string_statistics.cpp"

#include "src/storage/statistics/struct_statistics.cpp"

#include "src/storage/statistics/validity_statistics.cpp"

#include "src/storage/storage_info.cpp"

#include "src/storage/storage_lock.cpp"
